#include <sys/types.h>
#include <stdio.h>
#include <assert.h>
#include <errno.h>

int getline(lineptr, n, stream)
char **lineptr;
size_t *n;
FILE *stream;
{
  // do nothing implementation
  //  we don't use these functionalities of freesasa
  return 0;
}
